@@ -1,4 +1,3 @@
-# Webhooks
 from .webhook import Webhook
 from .client import TwikeyClient
 from .document import DocumentFeed
@@ -7,3 +6,14 @@ from .paylink import PaylinkFeed
 from .invoice import InvoiceFeed
 from .refund import RefundFeed
 from .client import TwikeyError
+
+__all__ = [
+    "Webhook",
+    "TwikeyClient",
+    "TwikeyError",
+    "DocumentFeed",
+    "TransactionFeed",
+    "PaylinkFeed",
+    "InvoiceFeed",
+    "RefundFeed",
+]
